Micron Document
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
| SparkN0de-git | SparkN0de |
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------


Commit 62e4ec000102257cb9c0c2c384f0fc7853b197fe


Parents : 89631d0
Author : Ivan <ivan@quad4.io>
Signature : Signature validation error
Date : 2026-04-13T14:32:10-05:00

fix(setup): update default Python version in setup script to 3.14

Changes

1 files changed, 2 insertions(+), 2 deletions(-)


Diff

diff --git a/scripts/ci/setup-python.sh b/scripts/ci/setup-python.sh
index 92d3ad6d..64f5e09e 100755
--- a/scripts/ci/setup-python.sh
+++ b/scripts/ci/setup-python.sh
@@ -3,12 +3,12 @@
# Source: https://www.python.org
#
# Usage: setup-python.sh [version]
# version: exact (3.13.9) or minor (3.13, resolved to latest patch).
set -eu
. "$(dirname "$0")/priv.sh"
-PY_INPUT="${1:-3.13}"
+PY_INPUT="${1:-3.14}"
CURRENT="$(python3 --version 2>/dev/null | sed 's/Python //')" || true
@@ -3,12 +3,12 @@
#
# Usage: setup-python.sh [version]
-# version: exact (3.13.9) or minor (3.13, resolved to latest patch).
+# version: exact (3.14.x) or minor (3.14, resolved to latest patch).
set -eu
. "$(dirname "$0")/priv.sh"


──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────